@@ -3,7 +3,7 @@ use base qw{Package::New};
 use strict;
 use warnings;
 
-our $VERSION='0.05';
+our $VERSION='0.08';
 
 =head1 NAME
 
@@ -14,14 +14,14 @@ Package::New::Dump - Simple base package from which to inherit
   package My::Package;
   use base qw{Package::New::Dump}; #provides new, initialize and dump
 
-=head1 RECOMMENDATIONS
-
-I recommend using this package only during development and reverting back to L<Package::New> when in full production
-
 =head1 DESCRIPTION
 
 The Package::New::Dump object provides a consistent object constructor for objects.
 
+=head1 RECOMMENDATIONS
+
+I recommend using this package only during development and reverting back to L<Package::New> when in full production
+
 =head1 USAGE
 
 =head1 CONSTRUCTOR
@@ -39,13 +39,16 @@ Returns the object serialized by L<Data::Dumper>
 =cut
 
 sub dump {
-  my $self=shift();
+  my $self  = shift;
+  my $depth = shift;
+  $depth    = 2 unless defined $depth;
+  local $@;
   eval 'use Data::Dumper qw{}';
-  if ($@) {
+  my $error = $@;
+  if ($error) {
     return wantarray ? () : '';
   } else {
-    my $depth=shift; $depth=2 unless defined $depth;
-    my $d=Data::Dumper->new([$self]);
+    my $d = Data::Dumper->new([$self]);
     $d->Maxdepth($depth);
     return $d->Dump;
   }
